Propagator

Struct Propagator 

pub struct Propagator { /* private fields */ }
A utility for computing Conventions. Given the Convention at the end of a piece of code, this utility can calculate the Convention at the beginning.

Implementations

Source

impl Propagator

pub fn new(after: &Convention) -> Self

Constructs a Propagator given the Convention after the code.

pub fn insert(&mut self, src: impl IntoVariable)

Adds src to lives.

pub fn remove(&mut self, dest: impl IntoVariable)

Removes dest from lives.

pub fn branch(&mut self, other: &Convention)

Propagate information backwards through a conditional branch. Variables live in other are added to lives.

pub fn switch<'a, C>( discriminant: Variable, switch: &'a Switch<C>, to_convention: impl Fn(&C) -> &'a Convention, ) -> Self

Propagate information backwards through a Switch. Variables live in every case of switch are included in lives, along with discriminant.

pub fn action(&mut self, action: Action)

Propagate information backwards through action. Variables written by action are removed from lives and those read by it are added.

pub fn before(&self) -> Convention

Returns the Convention before the code.